==> SyL-0.8.3.tar.gz: SyL/include/framework/Controller/SyL_ControllerAjax.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerAjax.php,v 1.3 2007/02/12 10:39:51 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ǡ饹
 */
require_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';

/**
 * Ajaxȥ饯饹
 *
 * ++ ܥ٥
 *   1. initStream       - ȥ顼Υ󥹥ȥ饯¹Ը
 *   2.   executeStream  - ¹
 *   3.   renderStream   - ӥ塼ɽ¹
 *   4. finalStream      - shutdown
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerAjax.php,v 1.3 2007/02/12 10:39:51 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ControllerAjax extends SyL_Controller
{
    /**
     * ե륿ե̾
     *
     * @access private
     * @var string
     */
    var $action_file_name = 'actions.xml';

    /**
     * 󥹥ȥ饯
     *
     * @access public
     * @param array Ķ
     */
    function SyL_ControllerAjax($config)
    {
        // 󥭡
        if (isset($config['action_key']) && $config['action_key']) {
            define('SYL_ACTION_KEY', $config['action_key']);
        } else {
            trigger_error("[SyL error] Controller parameter action_key not exists", E_USER_ERROR);
        }

        // ƤΥ󥹥ȥ饯
        parent::SyL_Controller($config);
    }

    /**
     * 
     *
     * @access protected
     */
    function initStream()
    {
        // Х륳ݡͥե
        $config_file = array();
        $config_file['components'] = SYL_WEBAPP_CONFIG_DIR . "/{$this->components_file_name}";
        // ٥ȼ¹
        $this->raiseEvent('initStream', $config_file);
        
        if ($this->container->isComponent('request')) {
            $request =& $this->container->getComponent('request');
            $parameter =& $request->getParameterObject();
            $parameter->applyParameters('mb_convert_encoding', SYL_ENCODE_INTERNAL, SYL_ENCODE_AJAX);
        }
    }

    /**
     * ¹
     *
     * @access protected
     */
    function executeStream()
    {
        // ¹Ƚ
        $config_file = array();
        // ե
        $config_file['actions'] = SYL_APP_DIR . "/{$this->action_file_name}";

        // ٥ȼ¹
        $this->raiseEvent('executeStream', $config_file);
    }

    /**
     * ȥݥ
     *
     * @access public
     */
    function stream()
    {
        // 
        $this->initStream();
        // ¹Խ
        $this->executeStream();
        // ӥ塼ɽ¹
        $this->renderStream();
/*
echo "<pre>";
print_r($this->container->components);
echo "</pre>";

*/
    }
}

?>

==> SyL-0.8.5.tar.gz: SyL/include/framework/Controller/SyL_ControllerAjax.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerAjax.php,v 1.4 2007/02/17 14:28:09 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ǡ饹
 */
require_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';

/**
 * Ajaxȥ饯饹
 *
 * ++ ܥ٥
 *   1. initStream       - ȥ顼Υ󥹥ȥ饯¹Ը
 *   2.   executeStream  - ¹
 *   3.   renderStream   - ӥ塼ɽ¹
 *   4. finalStream      - shutdown
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ControllerAjax.php,v 1.4 2007/02/17 14:28:09 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ControllerAjax extends SyL_Controller
{
    /**
     * ե륿ե̾
     *
     * @access private
     * @var string
     */
    var $action_file_name = 'actions.xml';

    /**
     * 󥹥ȥ饯
     *
     * @access public
     * @param array Ķ
     */
    function SyL_ControllerAjax($config)
    {
        // 󥭡
        if (isset($config['action_key']) && $config['action_key']) {
            define('SYL_ACTION_KEY', $config['action_key']);
        } else {
            trigger_error("[SyL error] Controller parameter action_key not exists", E_USER_ERROR);
        }

        // ƤΥ󥹥ȥ饯
        parent::SyL_Controller($config);
    }

    /**
     * 
     *
     * @access protected
     */
    function initStream()
    {
        // Х륳ݡͥե
        $config_file = array();
        $config_file['components'] = SYL_WEBAPP_CONFIG_DIR . "/{$this->components_file_name}";
        // ٥ȼ¹
        $this->raiseEvent('initStream', $config_file);
    }

    /**
     * ¹
     *
     * @access protected
     */
    function loadStream()
    {
        // Хե륿ե
        $global_filters_file = SYL_WEBAPP_CONFIG_DIR . "/{$this->filter_file_name}";
        // ץꥱե륿ե
        $app_filters_file = SYL_APP_DIR . "/{$this->filter_file_name}";

        $config_file = array();
        $config_file['filters'] = $app_filters_file . PATH_SEPARATOR . $global_filters_file;

        // ٥ȼ¹
        $this->raiseEvent('loadStream', $config_file);
    }

    /**
     * ¹
     *
     * @access protected
     */
    function executeStream()
    {
        // ¹Ƚ
        $config_file = array();
        // ե
        $config_file['actions'] = SYL_APP_DIR . "/{$this->action_file_name}";

        // ٥ȼ¹
        $this->raiseEvent('executeStream', $config_file);
    }

    /**
     * ȥݥ
     *
     * @access public
     */
    function stream()
    {
        // 
        $this->initStream();
        // ¹
        $this->loadStream();
        // ¹Խ
        $this->executeStream();
        // ӥ塼ɽ¹
        $this->middleStream();
        // ӥ塼ɽ¹
        $this->renderStream();
        // ӥ塼ɽ¹Ը
        $this->unloadStream();
/*
echo "<pre>";
print_r($this->container->components);
echo "</pre>";

*/
    }
}

?>
